@@ -1,9 +1,12 @@
-package PGP::CmdLine;
-
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Release_0_09 $
+#
+
+package PGP::CmdLine;
 
 use strict;
 
@@ -19,11 +22,18 @@ sub new
 
 sub getPassphrase
 {
-	print shift, ": ";
+	print STDERR shift, ": ";
 	system("stty -echo");
 	my $passphrase = <STDIN>;
-	chop($passphrase);
-	print "\n";
+	if (defined $passphrase)
+	{
+		chop($passphrase);
+	}
+	else
+	{
+		$passphrase = "";
+	}
+	print STDERR "\n";
 	system("stty echo");
 	$passphrase;
 }
@@ -35,7 +45,7 @@ sub getNewPassphrase
 		my $pass1 = getPassphrase("Please enter your passphrase");
 		my $pass2 = getPassphrase("Please re-enter your passphrase");
 		return $pass1 if ($pass1 eq $pass2);
-		print "Passphrases do not match - please retry.\n";
+		print STDERR "Passphrases do not match - please retry.\n";
 	}
 }
 
