@@ -1,9 +1,10 @@
-#!/usr/local/bin/perl -w
-
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Release_0_09 $
+#
 
 package PGP::KeyRingTrust;
 
@@ -16,15 +17,13 @@ use overload
 	'""' => \&asString;
 
 
-sub flags { shift->{'flags'}; }
+sub flags { my $self = shift; $$self; }
 
 sub new
 {
-	my $type = shift; my $self = {}; bless $self, $type;
-
-	$self->{'flags'} = shift;
-
-	$self;
+	my $type = shift;
+	my $self = shift;
+	bless \$self, $type;
 }
 
 sub restoreFromDataStream
@@ -40,7 +39,7 @@ sub saveToDataStream
 	my $self = shift;
 	my $dos = shift;
 
-	$dos->writeByte($self->{'flags'});
+	$dos->writeByte($self->flags());
 }
 
 sub asString
