@@ -1,9 +1,10 @@
-#!/usr/local/bin/perl -w
-
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Release_0_09 $
+#
 
 package PGP::LiteralData;
 
@@ -13,7 +14,7 @@ use Stream::Streamable;
 use strict;
 
 
-sub data { shift->{'_literal_data'}; }
+sub data { shift->{'literal_data'}; }
 
 sub new
 {   
@@ -23,7 +24,7 @@ sub new
 	$self->{'mode'} = 'b';	# Binary
 	$self->{'filename'} = '';
 	$self->{'timestamp'} = time();
-	$self->{'_literal_data'} = $msg;
+	$self->{'literal_data'} = $msg;
 
 	$self;
 }
@@ -36,7 +37,7 @@ sub restoreFromDataStream
 	$self->{'mode'} = $dis->read(1);
 	$self->{'filename'} = $dis->read($dis->readByte());
 	$self->{'timestamp'} = $dis->readTime();
-	$self->{'_literal_data'} = $dis->readAll();
+	$self->{'literal_data'} = $dis->readAll();
 
 	$self;
 }
