@@ -1,9 +1,10 @@
-#!/usr/local/bin/perl -w
-
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Release_0_09 $
+#
 
 package PGP::PublicKey;
 
@@ -18,9 +19,12 @@ use Math::MPI;
 use Crypt::MD5;
 
 
+sub n { shift->{'n'}; }
+sub e { shift->{'e'}; }
+
 sub new
 {
-	my $type = shift; my $self = {}; bless $self, $type;
+	my $class = shift; my $self = {}; bless $self, $class;
 
 	my $n = shift;
 	my $e = shift;
@@ -35,7 +39,7 @@ sub new
 
 sub restoreFromDataStream
 {
-	my $type = shift;
+	my $class = shift;
 	my $dis = shift;
 
 	my $n = restoreFromDataStream Math::MPI $dis; return $n unless ref($n);
@@ -52,8 +56,8 @@ sub saveToDataStream
 	my $self = shift;
 	my $dos = shift;
 
-	my $n = new Math::MPI $self->{'n'};
-	my $e = new Math::MPI $self->{'e'};
+	my $n = new Math::MPI $self->n();
+	my $e = new Math::MPI $self->e();
 
 	$n->saveToDataStream($dos);
 	$e->saveToDataStream($dos);
@@ -63,12 +67,27 @@ sub id
 {
     my $self = shift;
 
-	substr($self->{'n'}->save(), -8, 8);
+	substr($self->n()->save(), -8, 8);
 }
 
 sub fingerprint
 {
-	shift->fingerprintFromMessageDigest(new Crypt::MD5);
+	my $self = shift;
+	Crypt::MD5->hash($self->n()->save().$self->e()->save());
+}
+
+sub asString
+{   
+    my $self = shift;
+
+    my $n = $self->n();
+    my $e = $self->e();
+    my $fingerprint = $self->fingerprint();
+	 
+	my $retval = '';
+	$retval .= "  N = $n\n";
+	$retval .= "  E = $e\n";
+	$retval .= "  Fingerprint = $fingerprint\n";
 }
 
 1;
