@@ -1,9 +1,10 @@
-#!/usr/local/bin/perl -w
-
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.3 $
+# $State: Release_0_09 $
+#
 
 package PGP::UserId;
 
@@ -12,18 +13,19 @@ use Stream::Streamable;
 
 use strict;
 
+#
+#	This should have an overloaded comparison
+#
 use overload
 	'""' => \&asString;
 
-sub id { shift->{'id'}; }
+sub id { my $self = shift; $$self; }
 
 sub new
 {
-	my $type = shift; my $self = {}; bless $self, $type;
-
-	$self->{'id'} = shift;
-
-	$self;
+	my $type = shift;
+	my $self = shift;
+	bless \$self, $type;
 }
 
 sub restoreFromDataStream
@@ -39,9 +41,9 @@ sub saveToDataStream
 	my $self = shift;
 	my $dos = shift;
 
-	$dos->write($self->{'id'});
+	$dos->write($self->id());
 }
 
-sub asString { shift->{'id'}; }
+sub asString { "User id: ".shift->id(); }
 
 1;
